@@ -566,8 +566,8 @@ def test_get_arrivals_departures_observations():
                 "t_5940784_b_83572_tn_2",
                 "t_5940784_b_83572_tn_3",
             ],
-            "route_id": [401, 401, 401, 402, 402, 402],
-            "route_short_name": [401, 401, 401, 402, 402, 402],
+            "route_id": ["401", "401", "401", "402", "402", "402"],
+            "route_short_name": ["401", "401", "401", "402", "402", "402"],
             "direction_id": [0, 1, 1, 0, 0, 0],
             "scheduled_arrival_time": [
                 "14:00:00",
@@ -638,8 +638,8 @@ def test_get_arrivals_departures_observations_by_route():
                 "t_5940768_b_83572_tn_10",
                 "t_5940768_b_83572_tn_10",
             ],
-            "route_id": [401, 401, 401],
-            "route_short_name": [401, 401, 401],
+            "route_id": ["401", "401", "401"],
+            "route_short_name": ["401", "401", "401"],
             "direction_id": [0, 1, 1],
             "scheduled_arrival_time": [
                 "14:00:00",
@@ -705,8 +705,8 @@ def test_get_arrivals_departures_observations_by_vehicle():
                 "t_5940768_b_83572_tn_10",
                 "t_5940768_b_83572_tn_10",
             ],
-            "route_id": [401, 401, 401],
-            "route_short_name": [401, 401, 401],
+            "route_id": ["401", "401", "401"],
+            "route_short_name": ["401", "401", "401"],
             "direction_id": [0, 1, 1],
             "scheduled_arrival_time": [
                 "14:00:00",
@@ -771,6 +771,75 @@ def test_get_arrivals_departures_observations_invalid_date_range():
     assert df.empty
 
 
+@httpretty.activate
+def test_get_arrivals_departures_observations_leading_zeroes():
+    agency = "test_agency"
+    target_date = date(2023, 10, 1)
+    client = SwiftlyAPIClient(agency_key=agency, api_key="test_api_key")
+
+    url = client._format_url(client.ARRIVAL_DEPARTURE_OBSERVATIONS)
+
+    httpretty.register_uri(
+        httpretty.GET,
+        url,
+        responses=[
+            httpretty.Response(
+                body="""\
+block_id,trip_id,route_id,route_short_name,direction_id,stop_id,stop_name,stop_code,trip_headsign,departure_vehicle_id,arrival_vehicle_id,stop_order,gtfs_stop_sequence,trip_start_time,is_last_stop_of_trip,is_first_stop_of_trip,adjustment_ids,adjustment_types,adjustment_effects,schedule_adherence_secs,scheduled_arrival_time,scheduled_departure_time,observed_arrival_time,observed_departure_time,is_schedule_adherence_stop,service_date
+01,01,01,01,0,01,Route with Leading Zero,1,Route with Leading Zero,01,01,0,1,14:00:00,false,true,,,,,14:00:00,14:00:00,,,true,2024-12-01
+                """,
+                status=200,
+            ),
+        ],
+    )
+
+    df = client.get_arrivals_departures_observations(target_date)
+
+    expected_df = pd.DataFrame(
+        {
+            "block_id": ["01"],
+            "trip_id": ["01"],
+            "route_id": ["01"],
+            "route_short_name": ["01"],
+            "direction_id": [0],
+            "stop_id": ["01"],
+            "stop_name": ["Route with Leading Zero"],
+            "stop_code": [1],
+            "trip_headsign": ["Route with Leading Zero"],
+            "departure_vehicle_id": ["01"],
+            "arrival_vehicle_id": ["01"],
+            "stop_order": [0],
+            "gtfs_stop_sequence": [1],
+            "scheduled_arrival_time": ["14:00:00"],
+            "service_date": ["2024-12-01"],
+        }
+    )
+
+    # just compare some specific columns
+    assert df[
+        [
+            "block_id",
+            "trip_id",
+            "route_id",
+            "route_short_name",
+            "direction_id",
+            "stop_id",
+            "stop_name",
+            "stop_code",
+            "trip_headsign",
+            "departure_vehicle_id",
+            "arrival_vehicle_id",
+            "stop_order",
+            "gtfs_stop_sequence",
+            "scheduled_arrival_time",
+            "service_date",
+        ]
+    ].equals(expected_df)
+
+    sent_req = httpretty.last_request()
+    assert sent_req.querystring["startDate"] == ["10-01-2023"]
+
+
 @httpretty.activate
 def test_get_gps_playback():
     agency = "test_agency"
@@ -982,9 +1051,6 @@ def test_get_routes():
     ]
 
 
-
-
-
 @httpretty.activate
 def test_get_real_time_vehicles():
     agency = "test_agency"
@@ -1108,4 +1174,4 @@ def test_get_vehicles():
     vehicles = client.get_vehicles()
     vehicle_ids = [vehicle["externalId"] for vehicle in vehicles]
 
-    assert vehicle_ids == ["0096", "0101"]
\ No newline at end of file
+    assert vehicle_ids == ["0096", "0101"]
